/*
    __g2csensor_driver.h

-----------------------------------------------------------------------------

  This file is part of mikroSDK.
  
  Copyright (c) 2017, MikroElektonika - http://www.mikroe.com

  All rights reserved.

----------------------------------------------------------------------------- */

/**
@file   __g2csensor_driver.h
@brief    G2C_Sensor Driver
@mainpage G2C_Sensor Click
@{

@image html sch.jpg

@}

@defgroup   G2CSENSOR
@brief      G2C_Sensor Click Driver
@{

| Global Library Prefix | **G2CSENSOR** |
|:---------------------:|:-----------------:|
| Version               | **1.0.0**    |
| Date                  | **Apr 2019.**      |
| Developer             | **MikroE Team**     |

*/
/* -------------------------------------------------------------------------- */

#include "stdint.h"

#ifndef _G2CSENSOR_H_
#define _G2CSENSOR_H_

/** 
 * @macro T_G2CSENSOR_P
 * @brief Driver Abstract type 
 */
#define T_G2CSENSOR_P    const uint8_t*

/** @defgroup G2CSENSOR_COMPILE Compilation Config */              /** @{ */

//  #define   __G2CSENSOR_DRV_SPI__                            /**<     @macro __G2CSENSOR_DRV_SPI__  @brief SPI driver selector */
//  #define   __G2CSENSOR_DRV_I2C__                            /**<     @macro __G2CSENSOR_DRV_I2C__  @brief I2C driver selector */                                          
  #define   __G2CSENSOR_DRV_UART__                           /**<     @macro __G2CSENSOR_DRV_UART__ @brief UART driver selector */ 

                                                                       /** @} */
/** @defgroup G2CSENSOR_VAR Variables */                           /** @{ */



                                                                       /** @} */
/** @defgroup G2CSENSOR_TYPES Types */                             /** @{ */



                                                                       /** @} */
#ifdef __cplusplus
extern "C"{
#endif

/** @defgroup G2CSENSOR_INIT Driver Initialization */              /** @{ */

#ifdef   __G2CSENSOR_DRV_SPI__
void g2csensor_spiDriverInit(T_G2CSENSOR_P gpioObj, T_G2CSENSOR_P spiObj);
#endif
#ifdef   __G2CSENSOR_DRV_I2C__
void g2csensor_i2cDriverInit(T_G2CSENSOR_P gpioObj, T_G2CSENSOR_P i2cObj, uint8_t slave);
#endif
#ifdef   __G2CSENSOR_DRV_UART__
void g2csensor_uartDriverInit(T_G2CSENSOR_P gpioObj, T_G2CSENSOR_P uartObj);
#endif
                                                                       /** @} */
/** @defgroup G2CSENSOR_FUNC Driver Functions */                   /** @{ */

/**
 * @brief Write Single Byte
 *
 * @param[in] input 
 *
 * Writes sinle byte.
 */
void g2csensor_writeByte(uint8_t input);

/**
 * @brief Read Single Byte
 *
 * @return received byte
 *
 * Read received byte.
 */
uint8_t g2csensor_readByte();

/**
 * @brief Check for new byte received
 *
 * @retval 0 - no new data / 1 - data ready
 *
 * Checks is there a new byte received.
 */
uint8_t g2csensor_byteReady();

void g2csensor_enableDevice ( void );

void g2csensor_disableDevice ( void );

void g2csensor_resetDevice ( void );

void g2csensor_enableEcho ( void );

void g2csensor_disableEcho ( void );

void g2csensor_connectNetwork ( uint8_t *ssid, uint8_t *pass );

void g2csensor_disconnectNetwork ( void );

void g2csensor_connectBroker ( uint8_t *devid, uint8_t *pass );

void g2csensor_disconnectBroker ( void );

void g2csensor_commitData ( uint8_t *ref, uint8_t *val );

void g2csensor_publishData ( void );

                                                                       /** @} */
#ifdef __cplusplus
} // extern "C"
#endif
#endif

/**
    @example Click_G2C_Sensor_STM.c
    @example Click_G2C_Sensor_TIVA.c
    @example Click_G2C_Sensor_CEC.c
    @example Click_G2C_Sensor_KINETIS.c
    @example Click_G2C_Sensor_MSP.c
    @example Click_G2C_Sensor_PIC.c
    @example Click_G2C_Sensor_PIC32.c
    @example Click_G2C_Sensor_DSPIC.c
    @example Click_G2C_Sensor_AVR.c
    @example Click_G2C_Sensor_FT90x.c
    @example Click_G2C_Sensor_STM.mbas
    @example Click_G2C_Sensor_TIVA.mbas
    @example Click_G2C_Sensor_CEC.mbas
    @example Click_G2C_Sensor_KINETIS.mbas
    @example Click_G2C_Sensor_MSP.mbas
    @example Click_G2C_Sensor_PIC.mbas
    @example Click_G2C_Sensor_PIC32.mbas
    @example Click_G2C_Sensor_DSPIC.mbas
    @example Click_G2C_Sensor_AVR.mbas
    @example Click_G2C_Sensor_FT90x.mbas
    @example Click_G2C_Sensor_STM.mpas
    @example Click_G2C_Sensor_TIVA.mpas
    @example Click_G2C_Sensor_CEC.mpas
    @example Click_G2C_Sensor_KINETIS.mpas
    @example Click_G2C_Sensor_MSP.mpas
    @example Click_G2C_Sensor_PIC.mpas
    @example Click_G2C_Sensor_PIC32.mpas
    @example Click_G2C_Sensor_DSPIC.mpas
    @example Click_G2C_Sensor_AVR.mpas
    @example Click_G2C_Sensor_FT90x.mpas
*/                                                                     /** @} */
/* -------------------------------------------------------------------------- */
/*
  __g2csensor_driver.h

  Copyright (c) 2017, MikroElektonika - http://www.mikroe.com

  All rights reserved.

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions are met:

1. Redistributions of source code must retain the above copyright
   notice, this list of conditions and the following disclaimer.

2. Redistributions in binary form must reproduce the above copyright
   notice, this list of conditions and the following disclaimer in the
   documentation and/or other materials provided with the distribution.

3. All advertising materials mentioning features or use of this software
   must display the following acknowledgement:
   This product includes software developed by the MikroElektonika.

4. Neither the name of the MikroElektonika nor the
   names of its contributors may be used to endorse or promote products
   derived from this software without specific prior written permission.

THIS SOFTWARE IS PROVIDED BY MIKROELEKTRONIKA ''AS IS'' AND ANY
EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
DISCLAIMED. IN NO EVENT SHALL MIKROELEKTRONIKA BE LIABLE FOR ANY
DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
(INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
(INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

----------------------------------------------------------------------------- */

